:mod:`pjpersist` Revisioned Immutable Storage
=============================================

.. automodule:: shoobx.immutable.pjpersist

   .. autoclass:: Immutable
      :show-inheritance:
      :members:
      :special-members:
      :undoc-members:
      :member-order: bysource
      :exclude-members: __dict__, __implemented__, __module__, __provides__,
                        __providedBy__, __weakref__

   .. autoclass:: ImmutableContainer
      :show-inheritance:
      :members:
      :undoc-members:
      :member-order: bysource
